@@ -12,18 +12,21 @@ mod macros;
 mod add;
 mod add_mod;
 mod cmp;
+mod div;
 mod encoding;
 mod from;
 mod mul;
 mod neg_mod;
 mod shl;
 mod shr;
+mod sqrt;
 mod sub;
 mod sub_mod;
 
 #[cfg(feature = "generic-array")]
 mod array;
 
+mod bits;
 #[cfg(feature = "rand")]
 mod rand;
 
